@@ -1,25 +1,14 @@
-use crate::{
-    zest_block::ZestBlock,
-    zest_hash::zest4096,
-    zest_pad::{de_pad, to_blocks},
-};
+use crate::{zest_block::ZestBlock, zest_hash::zest4096, zest_pad::de_pad};
 
 // WARNING:
 // If the incorrect key is used, at least one byte
 // is taken off the output when it tries to de-pad it.
-pub fn zest_dec(input: &[u8], key: ZestBlock) -> Vec<u8> {
-    let cipher_blocks = to_blocks(input.to_vec());
+pub fn zest_dec(cipher_blocks: Vec<ZestBlock>, key: ZestBlock) -> Vec<u8> {
     let mut text_out = vec![];
     let mut counter = ZestBlock::new();
     for block in cipher_blocks {
-        let mut xored_input = key;
-        for i in 0..64 {
-            xored_input[i] ^= counter[i];
-        }
-        let mut hashed_out = zest4096(xored_input);
-        for i in 0..64 {
-            hashed_out[i] ^= block[i];
-        }
+        let mut hashed_out = zest4096(key ^ counter);
+        hashed_out ^= block;
         text_out.push(hashed_out);
         counter.increment_block();
     }
