@@ -19,8 +19,9 @@ pub fn de_pad(input: &mut Vec<u8>) {
 #[inline(always)]
 fn to_blocks(input: Vec<u8>) -> Vec<ZestBlock> {
     let mut blocks: Vec<ZestBlock> = vec![];
-    for block in input.array_chunks::<512>() {
-        blocks.push((*block).into());
+    for block in input.chunks_exact(512) {
+        let block_arr: [u8; 512] = block.try_into().unwrap();
+        blocks.push(block_arr.into());
     }
     blocks
 }
